@@ -21,11 +21,12 @@ STATUS_FAILED = 2
 
 
 class WebHook(object):
-    def __new__(cls, application, request):
+    @staticmethod
+    def create(application, request):
         user_agent = request.headers.get("User-Agent", None)
         if user_agent:
             if user_agent.startswith("GitHub"):
-                return GitHubWebHook(application, request)
+                return GitHubWebHook.create(application, request)
 
             raise Exception("User agent not supported: %s" % user_agent)
 
@@ -123,7 +124,8 @@ class WebHook(object):
 
 
 class GitHubWebHook(WebHook):
-    def __new__(cls, application, request):
+    @staticmethod
+    def create(application, request):
         event = request.headers["X-GitHub-Event"]
         if event == "push":
             return GitHubPushEvent(application, request)
